import type { SavedChecklist } from '../types'

const STORAGE_KEY = 'gocheck-saved-checklists'

export function saveChecklist(checklist: SavedChecklist) {
    try {
      const existingChecklists = loadSavedChecklists()
      const existingIndex = existingChecklists.findIndex(c => c.uuid === checklist.uuid);

      if (existingIndex > -1) {
        // Update lastOpened timestamp if checklist already exists
        existingChecklists[existingIndex].lastOpened = new Date().toISOString();
      } else {
        // Add new checklist with lastOpened timestamp
        existingChecklists.push({ ...checklist, lastOpened: new Date().toISOString() });
      }

      // Sort by lastOpened date in descending order
      existingChecklists.sort((a, b) => {
        if (!a.lastOpened) return 1;
        if (!b.lastOpened) return -1;
        return new Date(b.lastOpened).getTime() - new Date(a.lastOpened).getTime();
      });

      localStorage.setItem(STORAGE_KEY, JSON.stringify(existingChecklists));
    } catch (error) {
      console.error('Error saving checklist:', error);
    }
}

export const loadSavedChecklists = (): SavedChecklist[] => {
  const saved = localStorage.getItem(STORAGE_KEY)
  if (saved) {
  try {
    const parsed = JSON.parse(saved);
    if (Array.isArray(parsed)) {
      return parsed as SavedChecklist[];
    }
  } catch (error) {
    console.error('Error parsing saved checklists:', error);
  }
  }
  return []
}
